==> jc-1.4.0.tar.gz: java/beans/Introspector.h <==
// public class java.beans.Introspector

// class file dependencies
// @dep_class 90915c760769be4 java_beans_Introspector
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_Introspector_H_
#define _JC_java_beans_Introspector_H_

// Forward structure declarations
struct _jc_java_beans_BeanInfo$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_java_beans_Introspector$sub_refs	_jc_java_beans_Introspector$sub_refs;
typedef struct _jc_java_beans_Introspector$sub_nonrefs	_jc_java_beans_Introspector$sub_nonrefs;
typedef struct _jc_java_beans_Introspector$refs	_jc_java_beans_Introspector$refs;
typedef struct _jc_java_beans_Introspector$nonrefs	_jc_java_beans_Introspector$nonrefs;
typedef struct _jc_java_beans_Introspector$object	_jc_java_beans_Introspector$object;

typedef struct _jc_java_beans_Introspector$fields_struct	_jc_java_beans_Introspector$fields_struct;
typedef const struct _jc_java_beans_Introspector$vmethods	_jc_java_beans_Introspector$vmethods;
typedef const struct _jc_java_beans_Introspector$vtable	_jc_java_beans_Introspector$vtable;
typedef const struct _jc_java_beans_Introspector$vtype	_jc_java_beans_Introspector$vtype;

// Class fields structure
struct _jc_java_beans_Introspector$fields_struct {
	struct _jc_java_util_Hashtable$object	*beanInfoCache;
	_jc_object_array	*beanInfoSearchPath;
	jint	IGNORE__5fALL__5fBEANINFO;
	jint	IGNORE__5fIMMEDIATE__5fBEANINFO;
	jint	USE__5fALL__5fBEANINFO;
};
extern _jc_java_beans_Introspector$fields_struct _jc_java_beans_Introspector$class_fields;

// Constructors
extern void _jc_java_beans_Introspector$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_beans_Introspector$object *);

// Static methods
extern void _jc_java_beans_Introspector$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern struct _jc_object *_jc_java_beans_Introspector$method$copyBeanInfo$754d03fecb8dc5ed(_jc_env *, struct _jc_object *);
extern struct _jc_java_lang_String$object *_jc_java_beans_Introspector$method$decapitalize$7e702a0cc719f337(_jc_env *, struct _jc_java_lang_String$object *);
extern void _jc_java_beans_Introspector$method$flushCaches$dd64232aebfb47ee(_jc_env *);
extern void _jc_java_beans_Introspector$method$flushFromCaches$5233ce826c312ce1(_jc_env *, struct _jc_java_lang_Class$object *);
extern struct _jc_object *_jc_java_beans_Introspector$method$getBeanInfo$382ea66316e35d58(_jc_env *, struct _jc_java_lang_Class$object *);
extern struct _jc_object *_jc_java_beans_Introspector$method$getBeanInfo$6f8c1e65b031b17b(_jc_env *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_Class$object *);
extern _jc_object_array *_jc_java_beans_Introspector$method$getBeanInfoSearchPath$c05d1896ae30e295(_jc_env *);
extern void _jc_java_beans_Introspector$method$setBeanInfoSearchPath$6f4d0f1b4649828e(_jc_env *, struct _jc_object_array *);

// Virtual methods structure
struct _jc_java_beans_Introspector$vmethods {
};

// Vtable
struct _jc_java_beans_Introspector$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_Introspector$vmethods	java_beans_Introspector;
};

// Vtype
struct _jc_java_beans_Introspector$vtype {
	_jc_type			type;
	_jc_java_beans_Introspector$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_Introspector$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_beans_Introspector$refs {
    _jc_java_beans_Introspector$sub_refs	java_beans_Introspector;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_Introspector$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_Introspector$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_Introspector$sub_nonrefs	java_beans_Introspector;
};

// Object instance structure
struct _jc_java_beans_Introspector$object {
	_jc_java_beans_Introspector$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_Introspector$vtype	*vtype;
	_jc_java_beans_Introspector$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_Introspector$vtype _jc_java_beans_Introspector$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_Introspector, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_Introspector$class_object;

#endif	/* _JC_java_beans_Introspector_H_ */

==> jc-1.4.6.tar.gz: java/beans/Introspector.h <==
// public class java.beans.Introspector

// class file dependencies
// @dep_class 2bc4443843ba4104 java_beans_Introspector
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_beans_Introspector_H_
#define _JC_java_beans_Introspector_H_

// Forward structure declarations
struct _jc_java_beans_BeanInfo$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Hashtable$object;

// Typedefs
typedef struct _jc_java_beans_Introspector$sub_refs	_jc_java_beans_Introspector$sub_refs;
typedef struct _jc_java_beans_Introspector$sub_nonrefs	_jc_java_beans_Introspector$sub_nonrefs;
typedef struct _jc_java_beans_Introspector$refs	_jc_java_beans_Introspector$refs;
typedef struct _jc_java_beans_Introspector$nonrefs	_jc_java_beans_Introspector$nonrefs;
typedef struct _jc_java_beans_Introspector$object	_jc_java_beans_Introspector$object;

typedef struct _jc_java_beans_Introspector$fields_struct	_jc_java_beans_Introspector$fields_struct;
typedef const struct _jc_java_beans_Introspector$vmethods	_jc_java_beans_Introspector$vmethods;
typedef const struct _jc_java_beans_Introspector$vtable	_jc_java_beans_Introspector$vtable;
typedef const struct _jc_java_beans_Introspector$vtype	_jc_java_beans_Introspector$vtype;

// Class fields structure
struct _jc_java_beans_Introspector$fields_struct {
	struct _jc_java_util_Hashtable$object	*beanInfoCache;
	_jc_object_array	*beanInfoSearchPath;
	jint	IGNORE__5fALL__5fBEANINFO;
	jint	IGNORE__5fIMMEDIATE__5fBEANINFO;
	jint	USE__5fALL__5fBEANINFO;
};
extern _jc_java_beans_Introspector$fields_struct _jc_java_beans_Introspector$class_fields;

// Constructors
extern void _jc_java_beans_Introspector$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_beans_Introspector$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_beans_Introspector$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_beans_Introspector$method$copyBeanInfo$754d03fecb8dc5ed(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_beans_Introspector$method$decapitalize$7e702a0cc719f337(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_beans_Introspector$method$flushCaches$dd64232aebfb47ee(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java_beans_Introspector$method$flushFromCaches$5233ce826c312ce1(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_beans_Introspector$method$getBeanInfo$382ea66316e35d58(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_java_beans_Introspector$method$getBeanInfo$6f8c1e65b031b17b(_jc_env *, struct _jc_java_lang_Class$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_java_beans_Introspector$method$getBeanInfoSearchPath$c05d1896ae30e295(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java_beans_Introspector$method$setBeanInfoSearchPath$6f4d0f1b4649828e(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_beans_Introspector$vmethods {
};

// Vtable
struct _jc_java_beans_Introspector$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_beans_Introspector$vmethods	java_beans_Introspector;
};

// Vtype
struct _jc_java_beans_Introspector$vtype {
	_jc_type			type;
	_jc_java_beans_Introspector$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_beans_Introspector$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_beans_Introspector$refs {
    _jc_java_beans_Introspector$sub_refs	java_beans_Introspector;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_beans_Introspector$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_beans_Introspector$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_beans_Introspector$sub_nonrefs	java_beans_Introspector;
};

// Object instance structure
struct _jc_java_beans_Introspector$object {
	_jc_java_beans_Introspector$refs	refs[0];
	_jc_word		lockword;
	_jc_java_beans_Introspector$vtype	*vtype;
	_jc_java_beans_Introspector$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_beans_Introspector$vtype _jc_java_beans_Introspector$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_beans_Introspector, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_beans_Introspector$class_object;

#endif	/* _JC_java_beans_Introspector_H_ */
